@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.204-3-g114a6b3
+# git description: v4.205-1-g5fb9466
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.205';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.206';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -410,13 +410,9 @@ sub configure {
     [ 'Test::ReportPrereqs' => { ':version' => '0.004' } ], # include/exclude
   );
 
-  $self->add_plugins(
-    [ 'Test::ChangesHasContent' => { ':version' => '0.006' } ], # version-TRIAL
-
   # generated xt/ tests
     # Test::Pod::Spelling::CommonMistakes ?
       #Test::Pod::No404s # removed since it's rarely useful
-  ) if $self->open_source;
 
   if ( $spelling_tests ) {
     $self->add_plugins('Test::PodSpelling');
@@ -549,7 +545,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.205
+version 4.206
 
 =head1 SYNOPSIS
 
@@ -733,9 +729,6 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   [Test::ReportPrereqs]
   :version = 0.004
 
-  [Test::ChangesHasContent]
-  :version = 0.006
-
   [Test::PodSpelling]
 
   [@TestingMania]
